@@ -324,6 +324,7 @@ parameterize_pbtk <- function(
   PCs <- predict_partitioning_schmitt(
     parameters=schmitt.params,
     species=species,
+    default.to.human=default.to.human,
     adjusted.Funbound.plasma=adjusted.Funbound.plasma,
     regression=regression,
     minimum.Funbound.plasma=minimum.Funbound.plasma,
@@ -357,8 +358,8 @@ parameterize_pbtk <- function(
   outlist <- list()
   # Begin flows:
   #mL/min/kgBW^(3/4) converted to L/h/kgBW^(3/4):
-  QGFRc <- this.phys.data["GFR"]/1000*60 
-  Qcardiacc = this.phys.data["Cardiac Output"]/1000*60 
+  QGFRc <- this.phys.data["GFR"]/1000*60 # L/h/kgBW^(3/4) 
+  Qcardiacc = this.phys.data["Cardiac Output"]/1000*60 # L/h/kgBW^(3/4)
   flows <- unlist(lumped_params[substr(names(lumped_params),1,1) == 'Q'])
   
   outlist <- c(outlist,c(
@@ -429,8 +430,9 @@ parameterize_pbtk <- function(
              BW=BW,
              Vliverc=lumped_params$Vliverc, #L/kg
              Qtotal.liverc=
-               (lumped_params$Qtotal.liverf*as.numeric(Qcardiacc))/1000*60),
+               (lumped_params$Qtotal.liverf*as.numeric(Qcardiacc))), # L/h/kgBW^(3/4)
            suppress.messages=TRUE,
+           species = species,
            restrictive.clearance=restrictive.clearance)), #L/h/kg BW
       million.cells.per.gliver=110, # 10^6 cells/g-liver
       liver.density=1.05)) # g/mL
